
class JobType(object):
    transcode = 'urn:job:av.transcode'
    extract_poster = 'urn:job:av.poster'
    extract_storyboard = 'urn:job:av.storyboard'
    create_archive = 'urn:job:archive.create'
    extract_archive = 'urn:job:archive.extract'
    import_file = 'urn:job:import.file'
    replace_extra_metadata = 'urn:job:av.extra_metadata.replace'
    convert_font = 'urn:job:text.font.convert'
    subset_font = 'urn:job:text.font.subset'
    image_operation = 'urn:job:image.operation'
