from media_platform.media_platform_client import MediaPlatformClient
from media_platform.service.destination import Destination
from media_platform.service.file_descriptor import FileDescriptor
from media_platform.service.source import Source

Client = MediaPlatformClient

source = Source
destination = Destination

file_descriptor = FileDescriptor
